@@ -2,8 +2,8 @@
 """
 
 """
-import numpy as np
 
+from ..core import get_random_state
 from ..core.searcher import Searcher, OptimizeDirection
 from ..utils import logging
 
@@ -20,12 +20,13 @@ class Individual(object):
 
 
 class Population(object):
-    def __init__(self, size=50, optimize_direction=OptimizeDirection.Minimize):
+    def __init__(self, size=50, optimize_direction=OptimizeDirection.Minimize, random_state=None):
         assert isinstance(size, int)
         assert size > 0
         self.size = size
         self.populations = []
         self.optimize_direction = optimize_direction
+        self.random_state = random_state if random_state is not None else get_random_state()
 
     @property
     def initializing(self):
@@ -39,15 +40,14 @@ class Population(object):
         individual = Individual(space_sample, reward)
         self.populations.append(individual)
 
-    def sample_best(self, sample_size, random_state=np.random.RandomState()):
+    def sample_best(self, sample_size):
         if sample_size > self.length:
             sample_size = self.length
-        indices = sorted(random_state.choice(range(self.length), sample_size))
+        indices = sorted(self.random_state.choice(range(self.length), sample_size))
         samples = [self.populations[i] for i in indices]
         best = \
             sorted(samples,
-                   key=lambda i: i.reward if self.optimize_direction == OptimizeDirection.Minimize else -i.reward)[
-                0]
+                   key=lambda i: i.reward, reverse=self.optimize_direction in ['max', OptimizeDirection.Maximize])[0]
         return best
 
     def eliminate(self, num=1, regularized=False):
@@ -60,20 +60,19 @@ class Population(object):
                 eliminates.append(self.populations.pop(0))
             else:
                 # eliminate worst
-                worst = sorted(self.populations, key=lambda
-                    i: -i.reward if self.optimize_direction == OptimizeDirection.Minimize else i.reward)[
-                    0]
+                worst = sorted(self.populations, key=lambda i: i.reward,
+                               reverse=self.optimize_direction in ['min', OptimizeDirection.Minimize])[0]
                 self.populations.remove(worst)
                 eliminates.append(worst)
         return eliminates
 
     def shuffle(self):
-        np.random.shuffle(self.populations)
+        self.random_state.shuffle(self.populations)
 
     def mutate(self, parent_space, offspring_space):
         assert parent_space.all_assigned
         parent_params = parent_space.get_assigned_params()
-        pos = np.random.randint(0, len(parent_params))
+        pos = self.random_state.randint(0, len(parent_params))
         for i, hp in enumerate(offspring_space.params_iterator):
             if i > (len(parent_params) - 1) or not parent_params[i].same_config(hp):
                 hp.random_sample()
@@ -89,15 +88,50 @@ class Population(object):
 
 
 class EvolutionSearcher(Searcher):
+    """
+    Evolutionary Algorithm
+
+    References
+    ----------
+        Real, Esteban, et al. "Regularized evolution for image classifier architecture search." Proceedings of the aaai conference on artificial intelligence. Vol. 33. 2019.
+    """
+
     def __init__(self, space_fn, population_size, sample_size, regularized=False,
                  candidates_size=10, optimize_direction=OptimizeDirection.Minimize, use_meta_learner=True,
-                 space_sample_validation_fn=None):
+                 space_sample_validation_fn=None, random_state=None):
+        """
+        :param space_fn: callable, required
+            A search space function which when called returns a `HyperSpace` instance
+        :param population_size: int, required
+            Size of population
+        :param sample_size: int, required
+            The number of parent candidates selected in each cycle of evolution
+        :param regularized: bool
+            (default=False), Whether to enable regularized
+        :param candidates_size: int, (default=10)
+            The number of samples for the meta-learner to evaluate candidate paths when roll out
+        :param optimize_direction: 'min' or 'max', (default='min')
+            Whether the search process is approaching the maximum or minimum reward value.
+        :param use_meta_learner: bool, (default=True)
+            Whether to enable meta leaner. Meta-learner aims to evaluate the performance of unseen samples based on
+            previously evaluated samples. It provides a practical solution to accurately estimate a search branch with
+            many simulations without involving the actual training.
+        :param space_sample_validation_fn: callable or None, (default=None)
+            Used to verify the validity of samples from the search space, and can be used to add specific constraint
+            rules to the search space to reduce the size of the space.
+        """
         Searcher.__init__(self, space_fn=space_fn, optimize_direction=optimize_direction,
                           use_meta_learner=use_meta_learner, space_sample_validation_fn=space_sample_validation_fn)
-        self.population = Population(size=population_size, optimize_direction=optimize_direction)
+        self.random_state = random_state if random_state is not None else get_random_state()
+        self.population = Population(size=population_size, optimize_direction=optimize_direction,
+                                     random_state=self.random_state)
         self.sample_size = sample_size
         self.regularized = regularized
-        self.candidate_size = candidates_size
+        self.candidates_size = candidates_size
+
+    @property
+    def population_size(self):
+        return self.population.size
 
     @property
     def parallelizable(self):
@@ -122,7 +156,7 @@ class EvolutionSearcher(Searcher):
             candidates = []
             scores = []
             no = 0
-            for i in range(self.candidate_size):
+            for i in range(self.candidates_size):
                 new_space = self.space_fn()
                 try:
                     candidate = self._sample_and_check(lambda: self.population.mutate(space_sample, new_space))
@@ -135,9 +169,10 @@ class EvolutionSearcher(Searcher):
                 return None
 
             topn = sorted(scores,
-                          key=lambda s: s[1] if self.optimize_direction == OptimizeDirection.Minimize else -s[1])[
+                          key=lambda s: s[1],
+                          reverse=self.optimize_direction in ['max', OptimizeDirection.Maximize])[
                    :int(len(candidates) * 0.3)]
-            best = topn[np.random.choice(range(len(topn)))]
+            best = topn[self.random_state.choice(range(len(topn)))]
 
             if logger.is_info_enabled():
                 logger.info(f'get_offspring scores:{best[1]}, index:{best[0]}')
